/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWGUIQT_NAMESPACE_HPP__
#define __FWGUIQT_NAMESPACE_HPP__

/**
 * @brief       The namespace fwGuiQt contains classes which provide the implementation of the Gui using Qt library.
 * @namespace   fwGuiQt
 *
 * @date        2009-2010.
 *
 */

namespace fwGuiQt
{
}
#endif /* __FWGUIQT_NAMESPACE_HPP__ */
